@@ -18,6 +18,7 @@ use buffered_reader::BufferedReader;
 /// Block modes govern how a block cipher processes data spanning multiple blocks.
 pub(crate) trait Mode: Send + Sync {
     /// Block size of the underlying cipher in bytes.
+    #[allow(dead_code)] // Used in some backends.
     fn block_size(&self) -> usize;
 
     /// Encrypt a single block `src` to a ciphertext block `dst`.
@@ -38,7 +39,7 @@ pub(crate) trait Mode: Send + Sync {
         src: &[u8],
     ) -> Result<()>;
 }
-
+
 /// A `Read`er for decrypting symmetrically encrypted data.
 pub struct Decryptor<'a> {
     // The encrypted data.
@@ -60,14 +61,14 @@ impl<'a> Decryptor<'a> {
     where
         R: io::Read + Send + Sync + 'a,
     {
-        Self::from_buffered_reader(
+        Self::from_cookie_reader(
             algo, key,
             Box::new(buffered_reader::Generic::with_cookie(
                 source, None, Default::default())))
     }
 
     /// Instantiate a new symmetric decryptor.
-    fn from_buffered_reader(algo: SymmetricAlgorithm, key: &[u8],
+    fn from_cookie_reader(algo: SymmetricAlgorithm, key: &[u8],
                             source: Box<dyn BufferedReader<Cookie> + 'a>)
                             -> Result<Self>
     {
@@ -164,7 +165,7 @@ impl<'a> io::Read for Decryptor<'a> {
         Ok(pos)
     }
 }
-
+
 /// A `BufferedReader` that decrypts symmetrically-encrypted data as
 /// it is read.
 pub(crate) struct BufferedReaderDecryptor<'a> {
@@ -182,7 +183,7 @@ impl<'a> BufferedReaderDecryptor<'a> {
     {
         Ok(BufferedReaderDecryptor {
             reader: buffered_reader::Generic::with_cookie(
-                Decryptor::from_buffered_reader(algo, key, reader)?,
+                Decryptor::from_cookie_reader(algo, key, reader)?,
                 None, cookie),
         })
     }
@@ -264,7 +265,7 @@ impl<'a> BufferedReader<Cookie> for BufferedReaderDecryptor<'a> {
 
     fn into_inner<'b>(self: Box<Self>)
             -> Option<Box<dyn BufferedReader<Cookie> + 'b>> where Self: 'b {
-        Some(self.reader.into_reader().source.as_boxed())
+        Some(self.reader.into_reader().source.into_boxed())
     }
 
     fn cookie_set(&mut self, cookie: Cookie) -> Cookie {
@@ -425,7 +426,7 @@ mod tests {
 
         // Ensure we use CFB128 by default
         let iv = hex::decode("000102030405060708090A0B0C0D0E0F").unwrap();
-        let mut cfb = algo.make_encrypt_cfb(&key, iv).unwrap();
+        let mut cfb = algo.make_encrypt_cfb(key, iv).unwrap();
         let msg = hex::decode("6bc1bee22e409f96e93d7e117393172a").unwrap();
         let mut dst = vec![0; msg.len()];
         cfb.encrypt(&mut dst, &*msg).unwrap();
@@ -433,7 +434,7 @@ mod tests {
 
         // 32-byte long message
         let iv = hex::decode("000102030405060708090A0B0C0D0E0F").unwrap();
-        let mut cfb = algo.make_encrypt_cfb(&key, iv).unwrap();
+        let mut cfb = algo.make_encrypt_cfb(key, iv).unwrap();
         let msg = b"This is a very important message";
         let mut dst = vec![0; msg.len()];
         cfb.encrypt(&mut dst, &*msg).unwrap();
@@ -443,7 +444,7 @@ mod tests {
 
         // 33-byte (uneven) long message
         let iv = hex::decode("000102030405060708090A0B0C0D0E0F").unwrap();
-        let mut cfb = algo.make_encrypt_cfb(&key, iv).unwrap();
+        let mut cfb = algo.make_encrypt_cfb(key, iv).unwrap();
         let msg = b"This is a very important message!";
         let mut dst = vec![0; msg.len()];
         cfb.encrypt(&mut dst, &*msg).unwrap();
@@ -453,7 +454,7 @@ mod tests {
 
         // 33-byte (uneven) long message, chunked
         let iv = hex::decode("000102030405060708090A0B0C0D0E0F").unwrap();
-        let mut cfb = algo.make_encrypt_cfb(&key, iv).unwrap();
+        let mut cfb = algo.make_encrypt_cfb(key, iv).unwrap();
         let mut dst = vec![0; msg.len()];
         for (mut dst, msg) in dst.chunks_mut(16).zip(msg.chunks(16)) {
             cfb.encrypt(&mut dst, msg).unwrap();
@@ -533,6 +534,7 @@ mod tests {
     fn roundtrip() {
         use std::io::Cursor;
 
+        #[allow(deprecated)]
         for algo in [SymmetricAlgorithm::TripleDES,
                      SymmetricAlgorithm::CAST5,
                      SymmetricAlgorithm::Blowfish,
@@ -546,7 +548,7 @@ mod tests {
                      .iter()
                      .filter(|x| x.is_supported()) {
             let mut key = vec![0; algo.key_size().unwrap()];
-            crate::crypto::random(&mut key);
+            crate::crypto::random(&mut key).unwrap();
 
             let mut ciphertext = Vec::new();
             {
@@ -565,7 +567,7 @@ mod tests {
                 decryptor.read_to_end(&mut plaintext).unwrap();
             }
 
-            assert_eq!(&plaintext[..], &crate::tests::manifesto()[..]);
+            assert_eq!(&plaintext[..], crate::tests::manifesto());
         }
     }
 }
